pub enum FirecrackerNetworkOperation {
Add,
Check,
Delete,
}Expand description
An operation that can be made with a FirecrackerNetwork.
Variants
Add
Add this network to the host.
Check
Check that this network already exists on the host.
Delete
Delete this network from the host.