pub enum FirecrackerNetworkType {
Simple,
Namespaced {
netns_name: String,
veth1_name: String,
veth2_name: String,
veth1_ip: IpInet,
veth2_ip: IpInet,
forwarded_guest_ip: Option<IpAddr>,
},
}Expand description
The type of Firecracker network to work with.
Variants
Simple
Available on crate feature
simple only.A “simple” network configuration, with a tap device bound to the host interface via 1 set of forwarding rules. The most optimal and performant choice for the majority of use-cases.
Namespaced
Available on crate feature
namespaced only.A namespaced network configuration, with the tap device residing in a separate network namespace and being bound to the host interface via 2 sets of forwarding rules. The better choice exclusively for multiple running microVM sharing the same snapshot data (i.e. so-called “clones”).