pub struct FirecrackerNetwork {
pub nft_path: Option<String>,
pub ip_stack: FirecrackerIpStack,
pub iface_name: String,
pub tap_name: String,
pub tap_ip: IpInet,
pub guest_ip: IpInet,
pub network_type: FirecrackerNetworkType,
}Expand description
A configuration for a Firecracker microVM network.
Fields
nft_path: Option<String>The optional explicit path to “nft” to use when invoking it.
ip_stack: FirecrackerIpStackThe IP stack to use.
iface_name: StringThe name of the host network interface that handles real connectivity (i.e. via Ethernet or Wi-Fi).
tap_name: StringThe name of the tap device to direct Firecracker to use.
tap_ip: IpInetThe IP of the tap device to direct Firecracker to use.
guest_ip: IpInetThe IP of the guest.
network_type: FirecrackerNetworkTypeThe type of network to create, the available options depend on the feature flags enabled.
Implementations
Sourceimpl FirecrackerNetwork
impl FirecrackerNetwork
Sourcepub fn guest_ip_boot_arg(&self, guest_iface_name: impl AsRef<str>) -> String
pub fn guest_ip_boot_arg(&self, guest_iface_name: impl AsRef<str>) -> String
Format a kernel boot argument that can be added so that all routing setup in the guest is performed by the kernel automatically with iproute2 not needed in the guest.