pub enum FirecrackerNetworkType {
Simple,
}Expand description
The type of Firecracker network to work with.
Variants
Simple
A “simple” network configuration, with a tap device bound to the host interface via 1 set of forwarding rules. The most optimal and performant choice for the majority of use-cases.